@@ -12,9 +12,9 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "./main.h"
-#include "./moduleinfo.h"
-#include "./program.h"
+#include "main.h"
+#include "moduleinfo.h"
+#include "program.h"
 
 extern "C"
 {
